/*
 * Action.java
 * The package reservation contains the different class allowing to choose the action to realise.
 */
package reservation;

/**
 * This class uniform the way to call each sub-class (Create, Reserve, Cancel, Lists, Identify) that processes the commands.
 * It delegates to the sub-class the implementation of the function execute (), usage () and check ().
 * Also it masks the machinery and helps the developer who want to reuse the program.
 * @author Texier Mathieu and Frederic Bidon
 */
public interface Action {
    /**
     * Proceed the execution of the action
     * @param arg The argument of the coresponding function
     * @return The apropriate string message
     * @throws Exception When an error occurs
     */    
    String execute (String[] arg) throws Exception;
    /**
     * Maximal number of argument for the command mode
     */    
    static public final int NUMBER_ARGUMENT_MAX = 100;
    /**
     * The instance of the Flight System
     */    
    reservation.system.FlightSystem fs = reservation.system.FlightSystem.getInstance();
}

