/*
 * Panels.java
 * The package panels contains the different class executing the different windows of each function of the FlightSystem Reservation.
 */
package reservation.system.panels;

import reservation.Action;
import javax.swing.JPanel;

/**
 * This class uniform the way to call each sub-class (CreatePanel, ReservePanel, CancelPanel, Panel) that processes the commands.
 * It delegates to the sub-class the implementation of the function execute () and init ().
 * Also it masks the machinery and helps the developer who wants to reuse the program.
 * @author Texier Mathieu and Frederic Bidon
 */
abstract public class Panels extends JPanel implements Action {
    
    /**
     * Instantiate a new Panel
     */    
    public Panels () {
        super();
    }
    
    /**
     * Initialise the dialogsfield
     */    
    abstract public void init ();
    
    /**
     * Proceed the execution of the action
     * @param unUsed not used
     * @throws Exception if the command is not executed.
     * @return the result of the request.
     */    
    abstract public String execute (String[] unUsed) throws Exception;
    
    /**
     * Action requested
     */    
    protected Action action;
}